@@ -1,9 +1,8 @@
 from __future__ import annotations
 
-import threading
 import asyncio
 import functools
-
+import threading
 from typing import (
     TYPE_CHECKING,
     AsyncGenerator,
@@ -15,8 +14,8 @@ from typing import (
 )
 
 if TYPE_CHECKING:
+    from asyncio import Future, Task
     from threading import Thread
-    from asyncio import Task, Future
 
 
 def current_task_or_thread() -> Task | Thread:
@@ -87,9 +86,7 @@ async def merge_aiters(
     *aiters: AsyncIterator[T],
 ) -> AsyncIterator[Tuple[int, T]]:
     aiter_map = {a: i for i, a in enumerate(aiters)}
-    task_map = {
-        asyncio.ensure_future(a.__anext__()): a for a in aiter_map.keys()
-    }
+    task_map = {asyncio.ensure_future(a.__anext__()): a for a in aiter_map.keys()}
     tasks = set(task_map.keys())
     while tasks:
         done, pending = await asyncio.wait(
